mxewma: EWMA Control Chart for V and VSQ Statistics

View source: R/mxewma.R

mxewmaR Documentation

EWMA Control Chart for V and VSQ Statistics

Description

The mxewma function constructs an Exponentially Weighted Moving Average (EWMA) control chart for monitoring the V and VSQ statistics of a process. It calculates subgroup statistics, EWMA plotting statistics, control limits, and optionally displays a summary including estimated sigma.

Usage

mxewma(y, n = 4, lambada = 0.20, L = 3, chart = c("V", "VSQ"), summary = FALSE)

Arguments

y

A numeric vector of process observations.

n

Subgroup size. Default is 4.

lambada

EWMA smoothing parameter (0 < lambda <= 1). Default is 0.20.

L

Control limit multiplier. The value of L should be selected based on lambda according to established quality control references. Default is 3.

chart

Type of chart to construct: "V" or "VSQ" for square-rooted statistic. Default is c("V", "VSQ").

summary

Logical value indicating whether to print a summary of the chart, including estimated sigma. Default is FALSE.

Details

This function divides the input data y into subgroups of size n, and computes the V or VSQ statistic for each subgroup based on the single-parameter Maxwell distribution.

The Maxwell distribution is assumed as the underlying model for the process, and the subgroup statistics are constructed accordingly. The EWMA statistic is then computed to monitor small and moderate shifts in the process.The appropriate value of the multiplier L can be obtained from the cited references for selected values of lambda and sample size (n) to achieve an in-control Average Run Length (ARL0) of 370.

Dynamic control limits (LCL and UCL) are calculated at each subgroup using the EWMA formulation. For the VSQ chart, a constant a = (\sqrt{2}/\sqrt{3n}) (\Gamma((3n+1)/2)/\Gamma(3n/2)) is used to adjust the center line and control limits.

The estimated sigma is obtained as the mean of the subgroup statistics. The value of L should be selected corresponding to the smoothing parameter lambda based on established EWMA design tables available in the literature.

When summary = TRUE, the function prints a textual summary including the EWMA statistics, control limits, and the estimated sigma value.

Value

An invisible list containing the following components:

  • LCL: Lower Control Limit vector.

  • UCL: Upper Control Limit vector.

  • CL: Center Line.

  • Plotting_stat: EWMA statistics for each subgroup.

  • Statistic: Original subgroup statistic (V or VSQ).

  • m: Number of subgroups.

  • n: Subgroup size.

  • sigma: Estimated sigma (mean of subgroup statistics).

  • lambda: EWMA smoothing parameter.

  • L: Control limit multiplier.

  • chart: Chart type selected.

If summary = TRUE, a textual summary is also printed.

Author(s)

Zahid Khan

References

Hossain, M.P. and Riaz, M. (2021) "On designing a new VEWMA control chart for efficient process monitoring". Computers & Industrial Engineering, 162, 107751. <doi:10.1016/j.cie.2021.107751>

Khan, Z., Saghir, A., Katona, A. and KosztyƔn, Z.T. (2025) "EWMA control chart framework for efficient Maxwell quality characteristic monitoring: An application to the aerospace industry". Computers & Industrial Engineering, 200, 110753. <doi:10.1016/j.cie.2024.110753>

See Also

mxrpc, plot, summary

Examples

y <- c(
1.5391137, 2.2764737, 1.7794763, 2.3362682, 1.6382138, 1.6943709, 1.3135375, 0.5767501,
1.4950770, 2.2973635, 1.9949414, 2.6226897, 0.8730001, 2.1368288, 0.7282481, 1.7775871,
2.3898929, 2.3293989, 1.8709563, 2.5531137, 1.8444661, 1.7220544, 0.5774853, 1.6022162,
1.0952978, 0.4020387, 1.5097896, 1.8443609, 1.5732371, 0.8237968, 1.6290878, 1.0708337,
1.6846298, 0.8824187, 1.1953376, 1.6381853, 0.7522207, 3.2879978, 0.9592238, 0.7797138
)
mxewma(y, n = 4, lambada = 0.2, L = 3, chart = "VSQ", summary = FALSE)

mxewma(y, n = 4, lambada = 0.2, L = 3, chart = "V", summary = FALSE)

mxcc documentation built on April 10, 2026, 5:06 p.m.

Related to mxewma in mxcc...