| mxp | R Documentation |
The mxp function calculates the power of V chart and VSQ control chart for monitoring the Maxwell scale parameter. It computes the probability of detecting a shift in the process, depending on the specified sample size, significance level, and the shift magnitude
mxp(n = 1, alpha = 0.0027, delta = 1, type)
n |
The sample size for each subgroup (Integer). Default is |
alpha |
Probability of false alarm (type I error) for the control chart(numeric). Default is |
delta |
The shift constant representing the magnitude of the shift to detect(numeric). Default is |
type |
Specifies the type of control chart to be used. Options are |
The function calculates the power of a control chart based on the provided sample size (n), false alarm probability (alpha), and shift constant (delta). The chart type, either "V" or "VSQ", determines which chart is used for the calculations. Power is a critical metric that evaluates the sensitivity of the control chart to detecting process shifts, allowing users to monitor for deviations from the expected process behavior.
A numeric value representing the power of the control chart to detect the process shift.
Zahid Khan
Hossain, M.P., Omar, M.H. and Riaz, M. (2017) "New V control chart for the Maxwell distribution". Journal of Statistical Computation and Simulation, 87(3), pp.594-606. <doi:10.1080/00949655.2016.1222391>
Shah, F., Khan, Z., Aslam, M. and Kadry, S. (2021) "Statistical Development of the VSQ‐Control Chart for Extreme Data with an Application to the Carbon Fiber Industry". Mathematical Problems in Engineering, 2021(1), p.9766986. <doi:10.1155/2021/9766986>
result <- mxp(n = 5, alpha = 0.0027, delta = 2, type = "V")
print(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.