plot: Control Chart Plots for Maxwell-based V and VSQ Designs

plot.mxrpcR Documentation

Control Chart Plots for Maxwell-based V and VSQ Designs

Description

Constructs control charts for Maxwell-based quality characteristics. This method supports objects of class "mxrpc" (for real-world data) and "mxspc" (for simulated data).

Usage

## S3 method for class 'mxrpc'
plot(x, ...)
## S3 method for class 'mxspc'
plot(x, ...)

Arguments

x

An object of class "mxrpc" or "mxspc" generated by a Maxwell charting function.

...

Additional graphical parameters passed to the underlying plot function.

Details

These are S3 methods for the plot generic function, specialized for objects of class "mxrpc" and "mxspc".

Value

A control chart is drawn.

Author(s)

Zahid Khan

References

Hossain, M.P., Omar, M.H. and Riaz, M. (2017) "New V control chart for the Maxwell distribution". Journal of Statistical Computation and Simulation, 87(3), pp.594-606. <doi:10.1080/00949655.2016.1222391>

Shah, F., Khan, Z., Aslam, M. and Kadry, S. (2021) "Statistical Development of the VSQ‐Control Chart for Extreme Data with an Application to the Carbon Fiber Industry". Mathematical Problems in Engineering, 2021(1), p.9766986. <doi:10.1155/2021/9766986>

See Also

mxspc, mxrpc

Examples

t1 <- mxspc(m = 30, n = 4, alpha = 0.0027, sigma = 1777.86, limit = "PCL", chart = "V")
plot(t1)

mxcc documentation built on April 10, 2026, 5:06 p.m.

Related to plot in mxcc...