| print.mxrpc | R Documentation |
S3 print methods to display key parameters and summaries for control charts generated using mxrpc and mxspc, as well as their corresponding summary objects.
## S3 method for class 'mxrpc'
print(x, ...)
## S3 method for class 'mxspc'
print(x, ...)
## S3 method for class 'summary.mxrpc'
print(x, ...)
## S3 method for class 'summary.mxspc'
print(x, ...)
x |
An object of class |
... |
Additional arguments passed to or from other methods. |
These print methods provide structured output for:
Control chart parameters: subgroup number, sample size, control limits (LCL, CL, UCL or PCL), estimated sigma, limit type, and chart type.
Summary statistics for the plotting statistic (e.g., V values).
Summary of either real data (for mxrpc) or simulated data (for mxspc).
For summary objects (summary.mxrpc, summary.mxspc), control chart parameters and statistical summaries are displayed as formatted data frames.
Invisibly returns x after printing the relevant summaries to the console.
Zahid Khan, Zsolt T. Kosztyan
Hossain, M.P., Omar, M.H. and Riaz, M. (2017) "New V control chart for the Maxwell distribution". Journal of Statistical Computation and Simulation, 87(3), pp.594-606. <doi:10.1080/00949655.2016.1222391>
Shah, F., Khan, Z., Aslam, M. and Kadry, S. (2021) "Statistical Development of the VSQ‐Control Chart for Extreme Data with an Application to the Carbon Fiber Industry". Mathematical Problems in Engineering, 2021(1), p.9766986. <doi:10.1155/2021/9766986>
t1 <- mxspc(m = 20, n = 5, alpha = 0.004, sigma = 0.5, limit = "KCL")
print(t1)
print(summary(t1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.